# fedora-hyperreal.ks
#
# Description:
# - hyperreal's customized FedoraRemix Xfce kickstart
#
# Maintainer
# - Jeffrey Serio <hyperreal@fedoraproject.org>

# Installation Methods and Sources
url --mirrorlist=https://mirrors.fedoraproject.org/mirrorlist?repo=fedora-$releasever&arch=$basearch

# Storage and Partitioning
zerombr
network --bootproto=dhcp --device=link --activate --hostname=ravenwatch
ignoredisk --only-use=nvme1n1
clearpart --drives=nvme1n1 --all
autopart --type=btrfs --encrypted --noswap
bootloader --timeout=5

# Network Configuration
firewall --enabled --service=mdns

# Console and Environment
graphical
keyboard --vckeymap=us --xlayouts='us'
lang en_US.UTF-8
services --enabled=sshd,NetworkManager,chronyd,bluetooth
timezone America/Chicago
xconfig --startxonboot

# Installation Environment
graphical

# After the installation
firstboot --reconfig

%packages

# fedora-disk-base
kernel
kernel-modules
kernel-modules-extra
-kernel-lpae
dracut-config-generic
-dracut-config-rescue
aajohan-comfortaa-fonts
glibc-all-langpacks

# fedora-xfce-common
fedora-release-xfce
@^xfce-desktop-environment
@xfce-apps
@xfce-extra-plugins
@xfce-media
@xfce-office
wget
system-config-printer
-autofs
-acpid
-gimp-help
-desktop-backgrounds-basic
-aspell-*
-xfce4-sensors-plugin
-xfce4-eyes-plugin
xfce4-cpugraph-plugin
xfce4-docklike-plugin
xfce4-genmon-plugin
xfce4-clipman-plugin
xfce4-weather-plugin

# Fedora repo packages
ImageMagick
ShellCheck
autossh
bat
borgbackup
borgmatic
cmake
dnf-utils
emacs
fd-find
flatpak
fzf
golang
google-rubik-fonts
gstreamer1-plugin-openh264
gstreamer1-libav
gstreamer1-plugins-bad-free
gstreamer1-plugins-bad-free-extras
gstreamer1-plugins-bad-freeworld
gstreamer1-plugins-base
gstreamer1-plugins-good
gstreamer1-plugins-good-extras
gstreamer1-plugins-good-gtk
gstreamer1-plugins-good-qt
gstreamer1-plugins-good-qt6
httpie
hugo
inxi
just
lagrange
libtool
marked
mediawriter
mpv
neofetch
nmap
nodejs
nodejs-npm
openssl-devel
papirus-icon-theme
pass
podman-compose
prettyping
python3-devel
python3-pip
ripgrep
rofi
rofimoji
shfmt
snapper
trash-cli
vlc
w3m
wireshark
youtube-dl
zsh
'@c-development'
'@development-tools'
'@container-management'

%end

%post --log=/root/hyperreal-ks-post.log

# Configure DNF plugins
printf "fastestmirror=True\ndeltarpm=True\n" | tee -a /etc/dnf/dnf.conf

# Configure sudo for user
echo "jas ALL=(ALL) NOPASSWD: ALL" | tee /etc/sudoers.d/jas

# Add COPR repos
dnf copr enable -y atim/starship
dnf copr enable -y varlad/zellij
dnf copr enable -y hyperreal/better_fonts
dnf copr enable -y hyperreal/amfora
# Install COPR packages
dnf install -y starship zellij fontconfig-enhanced-defaults fontconfig-font-replacements amfora

# Add Charm repo
cat <<EOF > /etc/yum.repos.d/charm.repo
[charm]
name=Charm
baseurl=https://repo.charm.sh/yum/
enabled=1
gpgcheck=1
gpgkey=https://repo.charm.sh/yum/gpg.key
EOF

# Install Charm packages
dnf install -y charm glow gum skate wishlist

# Setup rpmfusion repos
dnf install -y \
    https://mirrors.rpmfusion.org/free/fedora/rpmfusion-free-release-$(rpm -E %fedora).noarch.rpm \
    https://mirrors.rpmfusion.org/nonfree/fedora/rpmfusion-nonfree-release-$(rpm -E %fedora).noarch.rpm

# Set vim as the default editor
dnf install -y --allowerasing vim-default-editor

# Install ffmpeg-libs and megasync
dnf install -y --allowerasing ffmpeg-libs

# Configure xdg-user-dirs
cat <<EOF > /etc/xdg/user-dirs.defaults
# Default settings for user directories
#
# The values are relative pathnames from the home directory and
# will be translated on a per-path-element basis into the users locale
DESKTOP=desktop
DOWNLOAD=downloads
TEMPLATES=
PUBLICSHARE=sync
DOCUMENTS=sync/documents
MUSIC=
PICTURES=sync/pictures
VIDEOS=
EOF

# Setup snapper services
systemctl enable snapper-cleanup.timer
systemctl enable snapper-timeline.timer

%end
